package org.qriterium.connection;

import org.qriterium.statement.QStatement;
import org.qriterium.util.XMLDataElement;
import org.qriterium.util.XMLProperties;

/**
 * Superclass for all connections
 * @author Mikko
 * @author Arto
 */
public abstract class QConnection extends QStatement 
									implements Connection {

	private Long toStatement;
    private Long fromStatement;

    /**
     * Constructs a new connection between the given QStatements
     * 
     * @param from the source connection
     * @param to the target connection
     * @param hash the source hash for this connection
     * @param rawId the raw id for this connection
     */
    public QConnection(Long from, Long to, String hash, String rawId) {
    	super(hash, rawId);
    	this.fromStatement = from;
    	this.toStatement = to;
    }
    
    public QConnection(long from, long to, String hash, String rawId) {
        this(new Long(from), new Long(to), hash, rawId);
    }

    /**
     * Convenience method for setFrom(Long)
     * @param from
     */
    public void setFrom(long from) {        
    	this.setFrom(new Long(from));
    }

    /**
     * Convenience method for setTo(Long)
     * @param to
     */
    public void setTo(long to) {        
    	this.setTo(new Long(to));
    }
    
    /**
     * Set the id of the target QStatement of this connection
     * @param to the id of the target QStatement of this connection
     */
    public void setTo(Long to) {
    	this.toStatement = to;    	
    }
    
    /**
     * Set the id of the source QStatement of this connection
     * @param from the id of the source QStatement of this connection
     */
    public void setFrom(Long from) {
    	this.fromStatement = from;    	
    }
    
    /**
     * Returns the id of the source QStatement of this connection
     * @return the id of the source QStatement of this connection
     */
    public Long getFrom() {        
    	return fromStatement;
    } 

    /**
     * Returns the id of the target QStatement of this connection
     * @return the id of the target QStatement of this connection
     */
    public Long getTo() {        
    	return toStatement;
    }
    
    /**
     * See QStatement.getStartTag()
     */
	public String getStartTag() {
		return XMLProperties.CONNECTION
			   + " type=\"" + this.getTypeString() + "\"";
	}
	
    /**
     * See QStatement.getEndTag()
     */
	public String getEndTag() {
		return XMLProperties.CONNECTION;
	}
	
    /**
     * QConnection data as an XMLDataElement[]
     * @return QConnection data
     */
	public XMLDataElement[] getXMLDataElements() {
    	XMLDataElement[] elements = {
    	  new XMLDataElement(XMLProperties.CONNECTION_FROM, this.getFrom().toString()),
    	  new XMLDataElement(XMLProperties.CONNECTION_TO, this.getTo().toString())
    	};
    	return elements;
	}
    
	public String toString() {
		return "QConnection <" + getFrom() + " " + getTypeString() + " " + getTo() + ">";
	}
    
    /**
     * Returns the type string of this connection
     * @return the type string of this connection
     */
    public abstract String getTypeString();

}
