package org.qriterium.settings;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
//import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Properties;
import java.util.logging.Logger;

public class Loader {
	private static Logger logger = Logger.getLogger("org.qriterium.transformer.DBLPTransformer");
	
	static String mainConfig = "settings" + File.separator + "boa.cfg";
	
	static String userDir; 
	static String sourceDir;
	static String dataDir;
	
	static ArrayList<Source> sources = new ArrayList<Source>();
	static ArrayList<User> users = new ArrayList<User>();
	
	static HashMap<String, User> nameMap = new HashMap<String, User>();

	public static void setMainConfig(String config) {
		mainConfig = config;
	}
	
	public static String getDataDir() {
		return dataDir;
	}

	public static ArrayList<Source> getSources() {
		return sources;
	}
	
	public static ArrayList<User> getUsers() {
		return users;
	}
	
	public static void loadSettings(String filename) {
		if (filename != null) {
			mainConfig = filename;
		}
		loadSettings();
	}
	
	public static void loadSettings() {
		String[] files;
		Properties prop;
		String fullname;
		
		// Read sourceDir and userDir from master configuration file		
		prop = readProperties(mainConfig);
		if (prop == null)
			return;
		
		userDir = prop.getProperty("userdir");
		sourceDir = prop.getProperty("sourcedir");
		dataDir = prop.getProperty("datadir");
	
		files = new File(userDir).list();
		if (files == null) {
			logger.severe("Error: Empty user directory " + userDir);
			return;
		}
		
		for (String file : files) {
			fullname = userDir + File.separator + file;
			if (new File(fullname).isDirectory())
				continue;
			
			prop = readProperties(fullname);
			if (prop == null)
				return;
			
			User user = new User();
			user.filename = file;
			user.name = prop.getProperty("name", "unknown");
			String idStr = prop.getProperty("id");
			
			if (idStr != null)
				user.id = Long.parseLong(idStr);
			else
				user.id = 1;
			
			nameMap.put(file, user);
			users.add(user);
		}
		
		files = new File(sourceDir).list(); 
		if (files == null) {
			logger.severe("Empty source directory " + sourceDir);
			return;
		}
		
		for (String file : files) {
			String str;
			
			fullname = sourceDir + File.separator + file;
			if (new File(fullname).isDirectory())
				continue;
			
			prop = readProperties(fullname);
			if (prop == null)
				return;
			
			Source source = new Source();
			source.filename = file;
			
			// TODO reasonable default values
			source.name = prop.getProperty("name");
			source.inputDir = prop.getProperty("inputdir");
			source.outputDir = prop.getProperty("outputdir");
			source.dataDir = prop.getProperty("datadir");
			source.transformer = prop.getProperty("transformer");
			source.printer = prop.getProperty("printer");
			
			source.outputFilename = prop.getProperty("outputfile");
			
			str = prop.getProperty("cutsize");
			if (str != null)
				source.cutSize = Long.parseLong(str);
			else
				source.cutSize = 0;
			
			str = prop.getProperty("gzip");
			if (str != null)
				source.gzip = Boolean.parseBoolean(str);
			else
				source.gzip = false;
			
			source.user = nameMap.get(prop.getProperty("user"));
			
			sources.add(source);
		}
		
		logger.info("Configuration finished.");
	}

	private static Properties readProperties(String filename) {
		Properties prop = null;

		logger.info("Reading configuration file " + filename);
			
		try {
			FileInputStream in  = new FileInputStream(filename);
			prop = new Properties();
			prop.load(in);
			in.close();
		} catch (FileNotFoundException e) {
			System.out.println("Cannot find file : " + filename);
		} catch (Exception e) {
			System.out.println(e);
		}
		
		return prop;
	}
}
