package org.qriterium.statement;

import org.qriterium.util.XMLDataElement;
import org.qriterium.util.XMLProperties;

/**
 * Superclass for all actors
 * @author Mikko
 * @author Arto
 */
public abstract class QActor extends QStatement {

	private String name;
	
	/**
	 * Constructs a new QActor with the String name
	 * @param name the name of the actor
	 * @param hash the source hash of this actor
	 * @param rawId the raw id of the actor
	 */
	public QActor(String name, String hash, String rawId) {
		super(hash, rawId);
		this.name = name;
	}
	
	/**
	 * Sets the name of this actor to the given String
	 * @param name the name given to the actor
	 */
	public void setName(String name) {
		this.name = name;
	}
	
	/**
	 * Returns the full name of this actor 
	 * @return the full name of this actor
	 */
	public String getName() {
		return name;
	} 
	
	/**
	 * See QStatement's isConnectable()
	 */
	public boolean isConnectable() {
		return super.isConnectable();
	}
	
    /**
     * See QStatement.getEndTag()
     */
	public String getStartTag() {
		return XMLProperties.ACTOR
			   + " type=\"" + this.getSubTypeString() +"\"";
	}
	
    /**
     * See QStatement.getEndTag()
     */
	public String getEndTag() {
		return XMLProperties.ACTOR;
	}
	
    /**
     * QActor data as an XMLDataElement[]
     * @return QActor data
     */
	public XMLDataElement[] getXMLDataElements() {
    	XMLDataElement[] elements = {
    	  new XMLDataElement(XMLProperties.ACTOR_RAWNAME, this.getName())
    	};
    	return elements;
	}

	/**
	 * Returns the subtype of this actor 
	 * @return the subtype of this actor
	 */
	public abstract String getSubTypeString();

	public String toString() {
		return super.toString() + " QActor: " + this.name;
	}	
}
