package org.qriterium.statement;

import org.qriterium.util.XMLDataElement;
import org.qriterium.util.XMLProperties;

/**
 * A QDocument-type QStatement
 * @author Mikko
 * @author Arto
 */
public class QDocument extends QStatement {

	private String title;
	private String language;
	private String filename;

    /**
     * Constructs a new QDocument
     * 
     * @param title the title of the document
     * @param language the language of the document
     * @param published the date when the document was published
     * @param hash the source hash for this document
     * @param rawId the raw id for this document
     */
	public QDocument(String title, 
					 String language,
					 String filename,
					 String hash,
					 String rawId) {
		super(hash, rawId);
		this.title = title;
		this.language = language;
		this.filename = filename;
		
		// XML output needs non-null values
		// DBLP transformer leaves null values in these fields
		if (this.language == null) {
			this.language = "";
		}
		if (this.filename == null) {
			this.filename = "";
		}
	}
	
	/**
     * Set the title of this QDocument
     * @param title the title of this QDocument
     */
	public void setTitle(String title) {        
		this.title = title;
    } 

	/**
     * Set the language of this QDocument
     * @param language the language of this QDocument
     */
	public void setLanguage(String language) {        
		this.language = language;
	} 

	/**
     * Set the OpenURL for this QDocument
     * @param url the OpenURL for this QDocument
     */
	public void setFilename(String filename) {        
		this.filename = filename;
	} 	
	
	/**
     * Returns the title of this QDocument
     * @return the title of this QDocument
     */
	public String getTitle() {        
		return this.title;
    } 

	/**
     * Returns the language of this QDocument
     * @return the language of this QDocument
     */
	public String getLanguage() {        
		return this.language;
	} 

	/**
     * Returns the OpenURL for this QDocument
     * @return the OpenURL for this QDocument
     */
	public String getFilename() {        
		return this.filename;
	} 
	
    /**
     * @see QStatement.getEndTag()
     */
	public String getStartTag() {
		return XMLProperties.DOCUMENT;
	}
	
    /**
     * @see QStatement.getEndTag()
     */
	public String getEndTag() {
		return XMLProperties.DOCUMENT;
	}
	
    /**
     * QDocument data as an XMLDataElement[]
     * @return QDocument data
     */
	public XMLDataElement[] getXMLDataElements() {
    	XMLDataElement[] elements = {
    	  new XMLDataElement(XMLProperties.DOCUMENT_RAWNAME, this.getTitle()),
    	  new XMLDataElement(XMLProperties.DOCUMENT_LANGUAGE, this.getLanguage()),
          new XMLDataElement(XMLProperties.DOCUMENT_FILENAME, this.getFilename())
    	};
    	return elements;
	}

	public String toString() {
		return super.toString() + " QDocument: " + this.title;
	}	
}
