package org.qriterium.statement;

import java.util.Date;
import java.text.DateFormat;
import java.text.SimpleDateFormat;

import org.qriterium.settings.SourceState;
import org.qriterium.util.XMLDataElement;
import org.qriterium.util.XMLProperties;

/**
 * Header class for all statement-objects
 * @author Mikko
 * @author Arto
 */
public class QHeader {

	/**
	 * DateFormat used by this software. 
	 * TODO Define a SimpleDateFormat here. 
	 */
	public static final DateFormat DATEFORMAT = new SimpleDateFormat("yyyy-MM-dd"); 
		//DateFormat.getDateInstance(DateFormat.MEDIUM, java.util.Locale.GERMANY);
	
	private long id;
	private String hash;
    private String rawId;
    private Date at;
    
    private long ssnr;
    private long ss;
    
    /**
     * Constructs a <code>QHeader</code> with the specified id, raw id,
     * datestamp and creation date. 
     * 
     * @param id Qriterium id
     * @param rawId raw id
     * @param datestamp datestamp
     * @param createDate creation date
     */
    public QHeader(long id, String hash, String rawId, Date at) {
    	this.id = id;
    	this.hash = hash;
    	this.rawId = rawId;
    	this.at = at;
    	
    	SourceState sourceState = SourceState.getActiveState();
    	if (sourceState != null) {  
	    	this.ssnr = sourceState.getNextSerialID();
	    	this.ss = sourceState.getSourceID();
	    	sourceState.setNextSerialID();
    	} else { 
    		// default values for testing purposes
    		this.ssnr = 1;
    		this.ss = 1;
    	}
    }
    
	/**
	 * Returns the Qriterium id of this header
	 * @return the Qriterium id of this header
	 */
    public long getId() {        
    	return this.id;
    } 

	/**
	 * Returns the source hash of this header
	 * @return the source hash of this header
	 */
    public String getHash() {        
    	return this.hash;
    } 
    
	/**
	 * Returns the raw id of this header
	 * @return the raw id of this header
	 */
    public String getRawId() {        
    	return this.rawId;
    } 

	/**
	 * Returns the creation date of this header
	 * @return the creation date of this header
	 */
    public Date getAt() {        
    	return at;
    } 
    
    /**
     * QHeader data as an XMLDataElement[]
     * TODO some elements need real values
     * @return QHeader data
     */
    public XMLDataElement[] getXMLDataElements() {
    	XMLDataElement[] elements = {
    	  new XMLDataElement(XMLProperties.HEADER_ID, 
    			  			 new Long(this.getId()).toString()),
    	  new XMLDataElement(XMLProperties.HEADER_RAWID, this.getRawId()),
    	  new XMLDataElement(XMLProperties.HEADER_HASH, this.getHash()),
    	  new XMLDataElement(XMLProperties.HEADER_STATEMENTSOURCE, "" + this.ss),
    	  new XMLDataElement(XMLProperties.HEADER_SSNR, "" + this.ssnr),
    	  new XMLDataElement(XMLProperties.HEADER_AT, DATEFORMAT.format(this.getAt()))
    	};
    	return elements;
    }

}