package org.qriterium.statement;

import java.net.URL;
import java.util.Date;

import org.qriterium.util.XMLDataElement;
import org.qriterium.util.XMLProperties;

/**
 * QSource-type QStatement
 * @author Mikko
 * @author Arto
 *
 */
public class QSource extends QStatement {

	private String name;
	private URL openurl;

	private String encoding;
	private String format;
	private String terminology;
	private String compression;
	private String backprotocol;
	private String toprotocol;
	private Date launched;
	
	/**
	 * Constructs a new QSource with the specified name and URL
	 * @param name the name of the QSource
	 * @param openurl the OpenURL of the QSource
	 * @param hash the source hash of the QSource
	 * @param rawId the raw id for this QSource
	 */
	public QSource(String name, URL openurl, String hash, String rawId) {
		super(hash, rawId);
		this.openurl = openurl;
		this.name = name;
	}

	/**
	 * Set the full name of this QSource 
	 * @param name the full name of this QSource
	 */
	public void setName(String name) {
		this.name = name;
	}
	
	/**
     * Set the OpenURL for this QSource
     * @param url the OpenURL for this QSource
     */
	public void setOpenURL(URL url) {        
		this.openurl = url;
	}
	
	/**
	 * Returns the full name of this QSource 
	 * @return the full name of this QSource
	 */
	public String getName() {
		return name;
	}
	
	/**
     * Returns the OpenURL for this QSource
     * @return the OpenURL for this QSource
     */
	public URL getOpenURL() {        
		return this.openurl;
	}

	/**
	 * @param encoding The encoding to set.
	 */
	public void setEncoding(String encoding) {
		this.encoding = encoding;
	}

	/**
	 * @return Returns the encoding.
	 */
	public String getEncoding() {
		return this.encoding;
	}

	/**
	 * @param format The format to set.
	 */
	public void setFormat(String format) {
		this.format = format;
	}

	/**
	 * @return Returns the format.
	 */
	public String getFormat() {
		return this.format;
	}

	/**
	 * @param terminology The terminology to set.
	 */
	public void setTerminology(String terminology) {
		this.terminology = terminology;
	}

	/**
	 * @return Returns the terminology.
	 */
	public String getTerminology() {
		return this.terminology;
	}

	/**
	 * @param compression The compression to set.
	 */
	public void setCompression(String compression) {
		this.compression = compression;
	}

	/**
	 * @return Returns the compression.
	 */
	public String getCompression() {
		return this.compression;
	}

	/**
	 * @param backprotocol The backprotocol to set.
	 */
	public void setBackprotocol(String backprotocol) {
		this.backprotocol = backprotocol;
	}

	/**
	 * @return Returns the backprotocol.
	 */
	public String getBackprotocol() {
		return this.backprotocol;
	}

	/**
	 * @param toprotocol The toprotocol to set.
	 */
	public void setToprotocol(String toprotocol) {
		this.toprotocol = toprotocol;
	}

	/**
	 * @return Returns the toprotocol.
	 */
	public String getToprotocol() {
		return this.toprotocol;
	}

	/**
	 * @param launched The launched to set.
	 */
	public void setLaunched(Date launched) {
		this.launched = launched;
	}

	/**
	 * @return Returns the launched.
	 */
	public Date getLaunched() {
		return this.launched;
	}
	
    /**
     * See QStatement.getEndTag()
     */
	public String getStartTag() {
		return XMLProperties.SOURCE;
	}
	
    /**
     * See QStatement.getEndTag()
     */
	public String getEndTag() {
		return XMLProperties.SOURCE;
	}
	
    /**
     * QSource data as an XMLDataElement[]
     * @return QSource data
     */
	public XMLDataElement[] getXMLDataElements() {
    	XMLDataElement[] elements = {
    		new XMLDataElement(XMLProperties.SOURCE_RAWNAME, this.name)
    	};
    	return elements;
	}
	
}
