/**
 * 
 */
package org.qriterium.statement;

import java.util.ArrayList;

import org.qriterium.io.StatementPrinter;
import org.qriterium.util.QConnectionHandler;
import org.qriterium.util.QStatementIndex;

/**
 * Maintains the main data structure (QStatements)
 * @author Arto
 */
public class QStatements {
	
	//private HashMap<Long,QStatement> statements;
	private QConnectionHandler connectionHandler;
	private QStatementIndex index;
	private ArrayList<StatementPrinter> listeners;
	
	public QStatements() {
		//this.statements = new HashMap<Long,QStatement>();
		this.connectionHandler = new QConnectionHandler(this);
		this.index = new QStatementIndex();
		this.listeners = new ArrayList<StatementPrinter>();
	}
	
	/**
	 * 
	 * @param statement
	 * @return true if the statement was added into the data structure, otherwise false
	 */
	public boolean addQStatement(QStatement statement) {
		/*
		if (this.statements.put(statement.getId(), statement) != null) {
			// The data structure already has an element of the given id (key).
			return false;
		}
		*/
		
		this.notifyPrinters(statement);
		
		//System.out.println("Statement added: " + statement);
		
		if (statement.isConnectable()) {
			addConnectionPoint(statement);
		}
		//System.err.println("added: " + statement.getId());
		return true;
	}
	
	/**
	 * Adds a QStatement to the index 
	 * @param statement QStament to be added
	 */
	public void addConnectionPoint(QStatement statement) {
		this.index.put(statement);
		this.connectionHandler.statementAdded(statement.getRawId());
	}

	public int checkConnectionToPoint(RawConnection connection) {
		return this.connectionHandler.statementAdded(connection.getTo());
	}
	
	/**
	 * Special method for RawConnections, passes the object to QConnectionHandler. 
	 * @param statement
	 * @return always false, because RawConnections are never added into the data structure
	 */
	public boolean addQStatement(RawConnection statement) {
		this.connectionHandler.addRawConnection(statement);
		return false;
	}
	
	/**
	 * Returns the QConnectionHandler instance.
	 * This is for testing purposes only.
	 * @return QConnectionHandler instance
	 */
	public QConnectionHandler getQConnectionHandler() {
		return this.connectionHandler;
	}

	/**
	 * Returns the QStatements.
	 * @return HashMap containing QStatements
	 */
	/*
	public HashMap<Long, QStatement> getStatements() {
		return statements;
	}
	*/
	
	/**
	 * A method for accessing the statement index
	 * @param rawId
	 * @return ID (Long) if rawId matches, otherwise null
	 */
	public Long getStatementIdByRawId(String rawId) {
		return this.index.get(rawId);
	}

	public QStatementIndex getIndex() {
		return index;
	}
	
	/**
	 * Adds a StatementPrinter as a new listener.
	 * @param printer
	 */
	public void addPrinter(StatementPrinter printer) {
		if (!this.listeners.contains(printer))
			this.listeners.add(printer);
	}
	
	/**
	 * Notifies every listening printer to close itself.
	 *
	 */
	public void finishPrinters() {
		for (StatementPrinter listener : this.listeners) {
			listener.close();
		}
	}
	
	private void notifyPrinters(QStatement statement) {
		for (StatementPrinter listener : this.listeners) {
			listener.print(statement);
		}
	}
	
}
