package org.qriterium.statement;

import org.qriterium.connection.Connection;
import org.qriterium.util.XMLDataElement;

import java.util.Date;

/**
 * Represents a future QConnection
 * RawConnection has the target part missing, thus, it is "raw".
 * QConnections will be created from RawConnections, when it becomes possible.
 * @author Arto
 *
 */
public class RawConnection extends QStatement 
							implements Connection {

	private String fromId;
	private String toId;
	private String type;
	
	/**
	 * Creates a new RawConnection
	 * 
	 * @param fromId RawId of the connection source
	 * @param toId RawId of the connection target
	 * @param connectionType String representation of the connection type
	 * @param hash the source hash for this connection
	 * @param rawId the raw id for this connection
	 */
	public RawConnection(String fromId, 
						 String toId, 
						 String connectionType,
						 String hash,
						 String rawId) {
		super(hash, rawId);
		this.fromId = fromId;
		this.toId = toId;
		this.type = connectionType;
	}
	
	public RawConnection(String fromId, 
						 String toId, 
						 String connectionType, 
						 String hash, 
						 String rawId, 
						 Date date) {
		super(hash, rawId, date);
		this.fromId = fromId;
		this.toId = toId;
		this.type = connectionType;
	}
	
	/**
	 * @return Connection-target's rawId
	 */
	public String getTo() {
		return this.toId;
	}
	
	/**
	 * @return Connection-source's rawId
	 */
	public String getFrom() {
		return this.fromId;
	}
	
	/**
	 * @return String representation of the type of this Connection
	 */
	public String getType() {
		return this.type;
	}
	
	public String toString() {
		return getFrom() + " " + getType() + " " + getTo();
	}

	/**
	 * A blank implementation, never used.
	 * @return null
	 */
	public XMLDataElement[] getXMLDataElements() {
		return null;
	}
	/**
	 * A blank implementation, never used.
	 * @return null
	 */
	public String getStartTag() {
		return null;
	}
	/**
	 * A blank implementation, never used.
	 * @return null
	 */
	public String getEndTag() {
		return null;
	}
}
