package org.qriterium.unit_tests.io;

import java.io.File;

import org.qriterium.io.QSPrinter;
import org.qriterium.statement.QDocument;

import junit.framework.TestCase;

/**
 * @author Timo
 * Does not reach 100% block coverage
 * Because:
 * - Two exceptions that are impossible to reach let alone simulate.
 */

public class QSPrinterTest extends TestCase {

	/*
	 * Test method for 'org.qriterium.util.QSPrinter.getFilePath() and setFilePath()'
	 */
	public void testGetFilePath() {
		QSPrinter printer = new QSPrinter();
		assertEquals("", printer.getFilePath());
		printer.setFilePath("foo");
		assertEquals("foo" + java.io.File.separator, printer.getFilePath());
		printer.setFilePath("bar" + java.io.File.separator);
		assertEquals("bar" + java.io.File.separator, printer.getFilePath());
	}

	/*
	 * Test method for 'org.qriterium.util.QSPrinter.getFilePrefix() and setFilePrefix()'
	 */
	public void testSetGetFileName() {
		QSPrinter printer = new QSPrinter();
		assertEquals(printer.DEFAULT_FILE_NAME, printer.getFileName());
		printer.setFileName("foo");
		assertEquals("foo", printer.getFileName());
		printer.setFileName("bar.xml");
		assertEquals("bar", printer.getFileName());
	}
	
	public void testGetOutputFile() {
		QSPrinter printer = new QSPrinter();
		printer.setFileName("foo");
		printer.setFilePath(System.getProperty("java.io.tmpdir"));
		assertEquals(System.getProperty("java.io.tmpdir") + "foo.xml", printer.getCurrentFileName());
		
		printer.setFileName("bar.xml");
		assertEquals(System.getProperty("java.io.tmpdir") + "bar.xml", printer.getCurrentFileName());
		
		printer.setFileName("baz.xml");
		printer.setGzip(true);
		assertEquals(System.getProperty("java.io.tmpdir") + "baz.xml.gz", printer.getCurrentFileName());
	}

	/*
	 * Test method for 'org.qriterium.util.QSPrinter.isGzip() and setGzip()'
	 */
	public void testIsGzip() {
		QSPrinter printer = new QSPrinter();
		assertEquals(false, printer.isGzip());
		printer.setGzip(true);
		assertEquals(true, printer.isGzip());
	}

	/*
	 * Test method for 'org.qriterium.util.QSPrinter.getOutputSize() and setOutputSize()'
	 */
	public void testGetOutputSize() {
		QSPrinter printer = new QSPrinter();
		assertEquals(0, printer.getOutputSize());
		printer.setOutputSize(10000);
		assertEquals(10000, printer.getOutputSize());
	}
	
	public void testPrint() {
		QSPrinter printer = new QSPrinter();
		printer.setFileName("JUnitTestOutput.xml");

		File outputFile = new File(printer.getCurrentFileName());
		if (outputFile.exists()) {
			outputFile.delete();
		}
		
		QDocument document = new QDocument("Fooing the Bar", "en", "foo.txt", "ASDFJKL", "raw:001");
		printer.print(document);
		assertTrue(outputFile.exists());
		printer.close();
	}
	
	public void testPrintGzip() {
		QSPrinter printer = new QSPrinter();
		printer.setFileName("JUnitTestOutput.xml");
		printer.setGzip(true);

		File outputFile = new File(printer.getCurrentFileName());
		if (outputFile.exists()) {
			outputFile.delete();
		}
		
		QDocument document = new QDocument("Fooing the Bar", "en", "foo.txt", "ASDFJKL", "raw:001");
		printer.print(document);
		assertTrue(outputFile.exists());
	}
	
	public void testPrintCutting() {
		QSPrinter printer = new QSPrinter();
		printer.setFileName("JUnitTestOutput.xml");
		printer.setOutputSize(1);

		QDocument document = new QDocument("Fooing the Bar", "en", "foo.txt", "ASDFJKL", "raw:001");
		printer.print(document);
		File outputFile1 = new File(printer.getCurrentFileName());
		assertTrue(outputFile1.exists());

		document = new QDocument("Baring around Baz", "en", "bar.txt", "LKJFDSA", "raw:002");
		printer.print(document);
		File outputFile2 = new File(printer.getCurrentFileName());
		assertTrue(outputFile2.exists());
		
		assertFalse(outputFile1.equals(outputFile2));
	}

	public void testPrintCuttingGzip() {
		QSPrinter printer = new QSPrinter();
		printer.setFileName("JUnitTestOutput.xml");
		printer.setOutputSize(1);
		printer.setGzip(true);

		QDocument document = new QDocument("Fooing the Bar", "en", "foo.txt", "ASDFJKL", "raw:001");
		printer.print(document);
		File outputFile1 = new File(printer.getCurrentFileName());
		assertTrue(outputFile1.exists());

		document = new QDocument("Baring around Baz", "en", "bar.txt", "LKJFDSA", "raw:002");
		printer.print(document);
		File outputFile2 = new File(printer.getCurrentFileName());
		assertTrue(outputFile2.exists());
		
		assertFalse(outputFile1.equals(outputFile2));
	}
}
