package org.qriterium.unit_tests.settings;

import java.util.ArrayList;

import org.qriterium.settings.FileState;
import org.qriterium.settings.SourceState;

import junit.framework.TestCase;

public class SourceStateTest extends TestCase {

    /*
     * Test method for 'org.qriterium.settings.SourceState.getActiveState()'
     */
    public void testGetActiveState() {
    	SourceState sourceState = new SourceState();
    	SourceState activeState = SourceState.getActiveState();
    	assertEquals(sourceState, activeState);
    }

    /*
     * Test method for 'org.qriterium.settings.SourceState.isCompleted(String)'
     */
    public void testIsCompleted() {
    	SourceState sourceState = new SourceState();
    	assertFalse(sourceState.isCompleted("test.xml"));
    	
    	sourceState.setFileState("test.xml", new FileState());
    	assertTrue(sourceState.isCompleted("test.xml"));
    }

    /*
     * Test method for 'org.qriterium.settings.SourceState.getFileNames()'
     */
    public void testGetFileNames() {
    	SourceState sourceState = new SourceState();
    	sourceState.setFileState("test.xml", new FileState());
    	sourceState.setFileState("test2.xml", new FileState());
    	
    	ArrayList<String> fileNames = new ArrayList<String>();
    	fileNames.add("test.xml");
    	fileNames.add("test2.xml");
    	
    	assertEquals(sourceState.getFileNames(), fileNames);
    }

    /*
     * Test method for 'org.qriterium.settings.SourceState.getFileState(String)'
     */
    public void testGetFileState() {
    	SourceState sourceState = new SourceState();
    	FileState fileState = new FileState();
    	sourceState.setFileState("test.xml", fileState);
    	assertTrue(sourceState.getFileState("test.xml") == fileState);
    	assertTrue(sourceState.getFileState("test2.xml") == null);    	
    }

    /*
     * Test method for 'org.qriterium.settings.SourceState.getNextFileID()'
     */
    public void testGetNextFileID() {
    	SourceState sourceState = new SourceState();
    	long fileId;
    	fileId = sourceState.getNextFileID();
    	sourceState.setNextFileID();
    	assertTrue(fileId + 1 == sourceState.getNextFileID());
    }

    /*
     * Test method for 'org.qriterium.settings.SourceState.getNextSerialID()'
     */
    public void testGetNextSerialID() {
    	SourceState sourceState = new SourceState();
    	long serialId;
    	serialId = sourceState.getNextSerialID();
    	sourceState.setNextSerialID();
    	assertTrue(serialId + 1 == sourceState.getNextSerialID());
    }


    /*
     * Test method for 'org.qriterium.settings.SourceState.setSourceID(long)'
     */
    public void testSetSourceID() {
    	SourceState sourceState = new SourceState();
    	long serialId;
    	serialId = sourceState.getNextSerialID();
    	sourceState.setNextSerialID();
    	assertTrue(serialId + 1 == sourceState.getNextSerialID());
    }

    /*
     * Test method for 'org.qriterium.settings.SourceState.getSourceID()'
     */
    public void testGetSourceID() {
    	SourceState sourceState = new SourceState();
    	sourceState.setSourceID(123);
    	assertTrue(sourceState.getSourceID() == 123);
    }

    /*
     * Test method for 'org.qriterium.settings.SourceState.getLastRun()'
     */
    public void testGetLastRun() {
    	SourceState sourceState = new SourceState();
    	assertTrue(sourceState.getLastRun() == null);
    	
    	sourceState.updateLastRun();
    	assertTrue(sourceState.getLastRun() != null);
    }

    /*
     * Test method for 'org.qriterium.settings.SourceState.toString()'
     */
    public void testToString() {
    	SourceState sourceState = new SourceState();
    	sourceState.setFileState("test.xml", new FileState());
    	sourceState.setFileState("test2.xml", new FileState());

    	assertEquals(sourceState.toString(), "SourceState [ test.xml test2.xml ]");
    }

}
