package org.qriterium.unit_tests.statement;

import junit.framework.TestCase;
import java.util.Date;
import java.net.URL;
import org.qriterium.statement.QSource;
import org.qriterium.util.XMLProperties;

/**
 * Unit test class for QSource 
 * @author Arto
 *
 */
public class QSourceTest extends TestCase {

	/*
	 * Test method for 'org.qriterium.statement.QSource.setName(String)'
	 */
	public void testSetName() {
		try {
			QSource s = new QSource("name", new URL("http://localhost/"), "foo", "foo");
			s.setName("foo");
			assertEquals("foo", s.getName());
		} catch (Exception e) { } 
	}

	/*
	 * Test method for 'org.qriterium.statement.QSource.setOpenURL(URL)'
	 */
	public void testSetOpenURL() {
		try {
			QSource s = new QSource("name", new URL("http://localhost/"), "foo", "foo");
			URL u = new URL("http://example.org");
			s.setOpenURL(u);
			assertEquals(u, s.getOpenURL());
		} catch (Exception e) { } 
	}

	/*
	 * Test method for 'org.qriterium.statement.QSource.setEncoding(String)'
	 */
	public void testSetEncoding() {
		try {
			QSource s = new QSource("name", new URL("http://localhost/"), "foo", "foo");
			s.setEncoding("UTF-8");
			assertEquals("UTF-8", s.getEncoding());
		} catch (Exception e) { } 
	}

	/*
	 * Test method for 'org.qriterium.statement.QSource.setFormat(String)'
	 */
	public void testSetFormat() {
		try {
			QSource s = new QSource("name", new URL("http://localhost/"), "foo", "foo");
			s.setFormat("application/xml");
			assertEquals("application/xml", s.getFormat());
		} catch (Exception e) { } 
	}

	/*
	 * Test method for 'org.qriterium.statement.QSource.setTerminology(String)'
	 */
	public void testSetTerminology() {
		try {
			QSource s = new QSource("name", new URL("http://localhost/"), "foo", "foo");
			s.setTerminology("Dublin Core");
			assertEquals("Dublin Core", s.getTerminology());
		} catch (Exception e) { } 
	}

	/*
	 * Test method for 'org.qriterium.statement.QSource.setCompression(String)'
	 */
	public void testSetCompression() {
		try {
			QSource s = new QSource("name", new URL("http://localhost/"), "foo", "foo");
			s.setCompression("application/x-compressed-tar");
			assertEquals("application/x-compressed-tar", s.getCompression());
		} catch (Exception e) { } 
	}

	/*
	 * Test method for 'org.qriterium.statement.QSource.setBackprotocol(String)'
	 */
	public void testSetBackprotocol() {
		try {
			QSource s = new QSource("name", new URL("http://localhost/"), "foo", "foo");
			s.setBackprotocol("http");
			assertEquals("http", s.getBackprotocol());
		} catch (Exception e) { } 
	}

	/*
	 * Test method for 'org.qriterium.statement.QSource.setToprotocol(String)'
	 */
	public void testSetToprotocol() {
		try {
			QSource s = new QSource("name", new URL("http://localhost/"), "foo", "foo");
			s.setToprotocol("qriterium");
			assertEquals("qriterium", s.getToprotocol());
		} catch (Exception e) { } 
	}

	/*
	 * Test method for 'org.qriterium.statement.QSource.setLaunched(Date)'
	 */
	public void testSetLaunched() {
		try {
			QSource s = new QSource("name", new URL("http://localhost/"), "foo", "foo");
			Date d = new Date();
			s.setLaunched(d);
			assertEquals(d, s.getLaunched());
		} catch (Exception e) { } 
	}
	
	public void testGetStartTag() {
		QSource s = new QSource(null, null, null, null);
		assertEquals(XMLProperties.SOURCE, s.getStartTag());
	}

	public void testGetEndTag() {
		QSource s = new QSource(null, null, null, null);
		assertEquals(XMLProperties.SOURCE, s.getEndTag());
	}
	
	public void testGetXMLDataElements() {
		QSource s = new QSource(null, null, null, null);
		assertEquals(1, s.getXMLDataElements().length);
	}

}
