package org.qriterium.unit_tests.statement;

import junit.framework.TestCase;
import org.qriterium.statement.*;
import org.qriterium.util.QStatementIndex;
import org.qriterium.connection.*;
import org.qriterium.io.ConsolePrinter;

/**
 * Unit test for QStatements
 * @author Arto
 *
 */
public class QStatementsTest extends TestCase {

	/*
	 * Test method for 'org.qriterium.statement.QStatements.addQStatement(QStatement)'
	 * Will also test QStatements.getStatements()
	 */
	public void testAddQStatementQStatement() {
		QStatements qs = new QStatements();
        
        ConsolePrinter printer = new ConsolePrinter();
        qs.addPrinter(printer);

		Person p = new Person("foo", null, null);
		//p.setHeader(new QHeader(1, null, null, null));

		Organization o = new Organization("bar", null, null);
		//o.setHeader(new QHeader(2, null, null, null));

		assertTrue(qs.addQStatement(p));
		assertTrue(qs.addQStatement(o));
		
		// p already added.
		//assertFalse(qs.addQStatement(p));
		
		//HashMap<Long,QStatement> map = qs.getStatements();
		//assertEquals(2, map.size());
		//assertEquals(map.get(p.getId()), p);
		//assertEquals(map.get(o.getId()), o);
	}

	/*
	 * Test method for 'org.qriterium.statement.QStatements.addQStatement(RawConnection)'
	 */
	public void testAddQStatementRawConnection() {
		QStatements qs = new QStatements();
		
		// creating the first end for a RawConnection (QConnection)
		QContent content = new QContent("foo", null);
		//content.setHeader(new QHeader(1, "foo", null, null));
		assertTrue(qs.addQStatement(content));
		//assertEquals(1, qs.getStatements().size());

		RawConnection rc = new RawConnection("foo", "bar", AwareOfConnection.TYPE, null, null);
		
		assertFalse(qs.addQStatement(rc));
		// should not be added as a QConnection at this point
		// because the other end of the RawConnection is missing.
		// thus, size() should still return 1.
		//assertEquals(1, qs.getStatements().size());
		
		Person p = new Person("pimp", "bar", null);
		//p.setHeader(new QHeader(2, "bar", null, null));
		// this should result in the creation of the foo-->bar QConnection
		assertTrue(qs.addQStatement(p));
		
	}
    
    public void testGetIndex() {
        QStatements qs= new QStatements();
        QStatementIndex ind = qs.getIndex();
        assertTrue(ind instanceof QStatementIndex);
    }
    
    public void testAddPrinter_and_finishPrinters() {
        QStatements qs = new QStatements();
        ConsolePrinter printer1 = new ConsolePrinter();
        assertFalse(printer1.closed());
        ConsolePrinter printer2 = new ConsolePrinter();
        assertFalse(printer2.closed());

        qs.addPrinter(printer1);
        qs.addPrinter(printer2);
        
        qs.finishPrinters();
        
        assertTrue(printer1.closed());
        assertTrue(printer2.closed());
    }

}
