package org.qriterium.unit_tests.transformer;

import junit.framework.TestCase;

import org.qriterium.transformer.*;
import org.qriterium.io.*;
import org.qriterium.statement.*;

/**
 * Unit test for CiteSeerTransformer
 * 
 * @author Mikko
 *
 */
public class CiteSeerTransformerTest extends TestCase {

	public void testTransform() {
		QStatements qs = new QStatements();
		try {
			CiteSeerTransformer	ct = 
				new CiteSeerTransformer();
		
			ct.transform(new FileReader("test.xml"), qs);
			
			assertEquals(21, ct.getStatementsCreated());
			assertEquals(1, ct.getValidItems());
			assertEquals(0, ct.getInvalidItems());
		} catch (Exception e) { }
	}

	public void testTransformPublisherKnown() {
		QStatements qs = new QStatements();
		try {
			CiteSeerTransformer	ct = 
				new CiteSeerTransformer();
		
			ct.transform(new FileReader("test_publisher_known.xml"), qs);
			
			assertEquals(23, ct.getStatementsCreated());
		} catch (Exception e) { }
	}
	
	public void testTransformNotWellFormed() {
		QStatements qs = new QStatements();
		try {
			CiteSeerTransformer	ct = 
				new CiteSeerTransformer();
		
			ct.transform(new FileReader("test_not_well_formed.xml"), qs);
			assertEquals(0, ct.getStatementsCreated());
			assertEquals(0, ct.getRecordsParsed());
			assertEquals(1, ct.getRecordsSkipped());
		} catch (Exception e) { }
	}
	
	public void testTransformHeaderMissing() {
		QStatements qs = new QStatements();
		try { 
			CiteSeerTransformer	ct = 
				new CiteSeerTransformer();
		
			ct.transform(new FileReader("test_header_missing.xml"), qs);
			assertEquals(0, ct.getStatementsCreated());
			assertEquals(0, ct.getRecordsParsed());
			assertEquals(1, ct.getRecordsSkipped());		
		} catch (Exception e) { }
	}

	public void testTransformMetadataMalformed() {
		QStatements qs = new QStatements();
		try {
		CiteSeerTransformer	ct = 
			new CiteSeerTransformer();
		
			ct.transform(new FileReader("test_metadata_malformed.xml"), qs);
			assertEquals(0, ct.getStatementsCreated());
			assertEquals(0, ct.getRecordsParsed());
			assertEquals(1, ct.getRecordsSkipped());
		} catch (Exception e) { }
	}

	public void testTransformMetadataIdentifierMissing() {
		QStatements qs = new QStatements();
		try {
			CiteSeerTransformer	ct = 
			new CiteSeerTransformer();
		
			ct.transform(new FileReader("test_metadata_identifier_missing.xml"), qs);
			assertEquals(0, ct.getStatementsCreated());
			assertEquals(0, ct.getRecordsParsed());
			assertEquals(1, ct.getRecordsSkipped());
		} catch (Exception e) { }
	}

	public void testTransformMetadataLanguageMissing() {
		QStatements qs = new QStatements();
		try {
			CiteSeerTransformer	ct = 
				new CiteSeerTransformer();	
		
			ct.transform(new FileReader("test_metadata_language_missing.xml"), qs);
			assertEquals(0, ct.getStatementsCreated());
			assertEquals(0, ct.getRecordsParsed());
			assertEquals(1, ct.getRecordsSkipped());
		} catch (Exception e) { }
	}
	
	public void testTransformMetadataPublisherMissing() {
		QStatements qs = new QStatements();
		try {
			CiteSeerTransformer	ct = 
				new CiteSeerTransformer();
		
			ct.transform(new FileReader("test_metadata_publisher_missing.xml"), qs);
			assertEquals(0, ct.getStatementsCreated());
			assertEquals(0, ct.getRecordsParsed());
			assertEquals(1, ct.getRecordsSkipped());
		} catch (Exception e) { }
	}

	public void testTransformMetadataTitleMissing() {
		QStatements qs = new QStatements();
		try {
			CiteSeerTransformer	ct = 
				new CiteSeerTransformer();
		
			ct.transform(new FileReader("test_metadata_title_missing.xml"), qs);
			assertEquals(0, ct.getStatementsCreated());
			assertEquals(0, ct.getRecordsParsed());
			assertEquals(1, ct.getRecordsSkipped());
		} catch (Exception e) { }
	}

	public void testTransformMetadataMalformedURL() {
		QStatements qs = new QStatements();
		try {
			CiteSeerTransformer	ct = 
				new CiteSeerTransformer();
			
			ct.transform(new FileReader("test_metadata_malformed_url.xml"), qs);
			assertEquals(0, ct.getStatementsCreated());
			assertEquals(0, ct.getRecordsParsed());
			assertEquals(1, ct.getRecordsSkipped());
		} catch (Exception e) { }
	}
	
	public void testTransformAuthorNoAttribute() {
		QStatements qs = new QStatements();
		try {
			CiteSeerTransformer	ct = 
				new CiteSeerTransformer();
		
			ct.transform(new FileReader("test_author_no_attribute.xml"), qs);
			assertEquals(0, ct.getStatementsCreated());
			assertEquals(0, ct.getRecordsParsed());
			assertEquals(1, ct.getRecordsSkipped());
		} catch (Exception e) { }
	}

	public void testTransformAuthorNoAuthors() {
		QStatements qs = new QStatements();
		try {
			CiteSeerTransformer	ct = 
				new CiteSeerTransformer();
		
			ct.transform(new FileReader("test_author_no_authors.xml"), qs);
			assertEquals(0, ct.getStatementsCreated());
			assertEquals(0, ct.getRecordsParsed());
			assertEquals(1, ct.getRecordsSkipped());
		} catch (Exception e) { }
	}

	public void testTransformReferencesMalformed() {
		QStatements qs = new QStatements();
		try {
			CiteSeerTransformer	ct = 
				new CiteSeerTransformer();
		
			ct.transform(new FileReader("test_references_malformed.xml"), qs);
			assertEquals(0, ct.getStatementsCreated());
			assertEquals(0, ct.getRecordsParsed());
			assertEquals(1, ct.getRecordsSkipped());
		} catch (Exception e) { }
	}
	
	public void testTransformReferencesNoURI() {
		QStatements qs = new QStatements();
		try {
			CiteSeerTransformer	ct = 
				new CiteSeerTransformer();
		
			ct.transform(new FileReader("test_references_no_uri.xml"), qs);
			assertEquals(0, ct.getStatementsCreated());
			assertEquals(0, ct.getRecordsParsed());
			assertEquals(1, ct.getRecordsSkipped());
		} catch (Exception e) { }
	}
	
	public void testTransformTotallyMessedUp1() {
		QStatements qs = new QStatements();
		try {
			CiteSeerTransformer	ct = 
				new CiteSeerTransformer();
		
			ct.transform(new FileReader("test_totally_messed_up1.xml"), qs);
			assertEquals(0, ct.getStatementsCreated());
			assertEquals(0, ct.getRecordsParsed());
			assertEquals(1, ct.getRecordsSkipped());
		} catch (Exception e) { }
	}
	
	public void testTransformTotallyMessedUp2() {
		QStatements qs = new QStatements();
		try {
			CiteSeerTransformer	ct = 
				new CiteSeerTransformer();
		
			ct.transform(new FileReader("test_totally_messed_up2.xml"), qs);
			assertEquals(0, ct.getStatementsCreated());
			assertEquals(0, ct.getRecordsParsed());
			assertEquals(1, ct.getRecordsSkipped());
		} catch (Exception e) { }
	}

}
