/**
 * 
 */
package org.qriterium.unit_tests.transformer;

import javax.xml.parsers.DocumentBuilderFactory;

import org.qriterium.io.FileReader;
import org.qriterium.statement.QStatements;
import org.qriterium.transformer.DBLPTransformer;
import org.w3c.dom.Document;

import junit.framework.TestCase;

/**
 * @author irkheikk
 *
 */
public class DBLPTransformerTest extends TestCase {

	/*
	 * Test method for 'org.qriterium.transformer.DBLPTransformer.transform()'
	 */
	public void testTransform() throws Exception {
		QStatements qs = new QStatements();
		DBLPTransformer dblpt = 
			new DBLPTransformer();
	
		dblpt.transform(new FileReader("test_dblp_sample.xml"), qs);
		
		assertEquals(9, dblpt.getStatementsCreated());
		assertEquals(1, dblpt.getValidItems());
		assertEquals(0, dblpt.getInvalidItems());
	}

	/*
	 * Test method for 'org.qriterium.transformer.DBLPTransformer.transform()'
	 */
	public void testTransformManyRecords() throws Exception {
		QStatements qs = new QStatements();
		DBLPTransformer dblpt = 
			new DBLPTransformer();
	
		dblpt.transform(new FileReader("test_dblp_sample_many_records.xml"), qs);
		
		assertEquals(52, dblpt.getStatementsCreated());
		assertEquals(6, dblpt.getValidItems());
		assertEquals(0, dblpt.getInvalidItems());
	}
	
	/*
	 * Test method for 'org.qriterium.transformer.DBLPTransformer.transform()'
	 */
	public void testTransformReferences() throws Exception {
		QStatements qs = new QStatements();
		DBLPTransformer dblpt = 
			new DBLPTransformer();
	
		dblpt.transform(new FileReader("test_dblp_sample_references.xml"), qs);
		
		assertEquals(24, dblpt.getStatementsCreated());
		assertEquals(1, dblpt.getValidItems());
		assertEquals(0, dblpt.getInvalidItems());
	}
	
	/*
	 * Test method for 'org.qriterium.transformer.DBLPTransformer.transform()'
	 */
	public void testTransformNotWellFormed() throws Exception {
		QStatements qs = new QStatements();
		DBLPTransformer dblpt = 
			new DBLPTransformer();
	
		dblpt.transform(new FileReader("test_dblp_sample_not_well_formed.xml"), qs);
		
		assertEquals(14, dblpt.getStatementsCreated());
		assertEquals(2, dblpt.getValidItems());
		assertEquals(1, dblpt.getInvalidItems());
	}


	public void testTransformNotFound() throws Exception {
		QStatements qs = new QStatements();
		DBLPTransformer dblpt = 
			new DBLPTransformer();
		try {
			dblpt.transform(new FileReader("__FILE__NOT__FOUND__.xml"), qs);
			assertTrue(false);
		} catch (Exception e) {
			assertTrue(true);
		}
	}
	
	public void testExtractTags() {
		DBLPTransformer dblpt = 
			new DBLPTransformer();
		try {
			Document d = DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument();
			String[] badTags = { "//#$@%^&(!(///./../bad_TAG///#!\\" };
			dblpt.extractTags(badTags, d);
		} catch (Exception e){}
	}
}
