package org.qriterium.unit_tests.util;

import junit.framework.TestCase;

import org.qriterium.connection.AwareOfConnection;
import org.qriterium.statement.*;

import org.qriterium.util.QConnectionHandler;

import java.text.DateFormat;
import java.util.HashMap;

/**
 * Unit test class for QConnectionHandler
 * @author Arto
 *
 */
public class QConnectionHandlerTest extends TestCase {

	private static HashMap<String,Object> tmpHash = new HashMap<String,Object>();

	/*
	 * Test method for 'org.qriterium.QConnectionHandler.addRawConnection(RawConnection)'
	 */
	public void testAddRawConnection() {
		QConnectionHandler handler = new QConnectionHandler(null);

		handler.addRawConnection(new RawConnection("foo", "bar", "test_type", null, null));
		assertEquals(1, handler.getHashSize());

		handler.addRawConnection(null);
		assertEquals(1, handler.getHashSize());
	}

	public void testStatementAdded() {
		
		QConnectionHandler nullStatements = new QConnectionHandler(null);
		assertEquals(0, nullStatements.statementAdded(null));
		
		//System.out.println("test start>");
		QStatements statements = new QStatements();
		QConnectionHandler handler = statements.getQConnectionHandler();
		
		// no null values..
		assertEquals(0, handler.statementAdded(null));
		
		// an unconnectable statement as the argument will result in a zero return value, always.
		//assertEquals(0, handler.statementAdded(new RawConnection(null,null,null,null,null)));
		
		try {
			// no rawconnections found for this one.
			assertEquals(0, handler.statementAdded(""));
		
			// adding the from-end.
			QContent contentFrom = new QContent(null, "foo");
			//contentFrom.setHeader(new QHeader(666, "foo", null, null));
			assertTrue(statements.addQStatement(contentFrom));
			
			// and the a RawConnection..
			handler.addRawConnection(new RawConnection("foo", "bar", AwareOfConnection.TYPE, null, null));
			assertEquals(1, handler.getHashSize());
		
			// the to-end is missing, no creation done.
            System.out.println("missing>");
			assertEquals(0, handler.statementAdded("bar"));
            System.out.println("<missing");
			
			//adding the target of the connection.
			QContent contentTo = new QContent(null, "bar");
            // now one QConnection should be created
			assertTrue(statements.addQStatement(contentTo));

             // rawconnection should have been disappeared
			assertEquals(0, handler.getHashSize());

			// no more QConnections to be made for this.
			assertEquals(0, handler.statementAdded(contentTo.getRawId())); 

			//more test data 
			QContent contentFrom2 = new QContent(null, "baz");
			//contentFrom2.setHeader(new QHeader(232300, "baz", null, null));
			assertTrue(statements.addQStatement(contentFrom2));
			// testing those cases when there are many QConnections to be made
			handler.addRawConnection(new RawConnection("foo", "bar", AwareOfConnection.TYPE, null, null));
			handler.addRawConnection(new RawConnection("baz", "bar", AwareOfConnection.TYPE, null, null));
			assertEquals(2, handler.getHashSize());
			
			// Two RawConnections are found, two QConnections are made.
			assertEquals(2, handler.statementAdded(contentTo.getRawId()));
			// no more left.
			assertEquals(0, handler.getHashSize());
		} catch (Exception e) {	}
	}
	
	public void testStore() {
		QConnectionHandler handler = new QConnectionHandler(null);

		RawConnection rc1 = new RawConnection("foo0", "bar", "test_type", null, null);
		RawConnection rc2 = new RawConnection("foo1", "bar", "test_type", null, null);
		RawConnection rc3 = new RawConnection("foo2", "bar0", "test_type2", null, null);
		
		DateFormat df = QHeader.DATEFORMAT;
		
		try {
			rc1.setHeader(new QHeader(0, "hash1", "raw", df.parse("2006-01-01")));
			rc2.setHeader(new QHeader(0, "hash1", "raw", df.parse("2006-01-01")));
			rc3.setHeader(new QHeader(0, "hash1", "raw", df.parse("2006-01-01")));
		} catch (java.text.ParseException e) { 
			assertFalse("should not go here!", true);
		}
		
		// memorize for other tests.. -->
		
		tmpHash.put("rawId", "raw");
		tmpHash.put("datestamp", "2006-01-01");
		//tmpHash.put("createDate", "01.01.2006");

		tmpHash.put("rc1_type", "test_type");
		tmpHash.put("rc2_type", "test_type");
		tmpHash.put("rc3_type", "test_type2");

		tmpHash.put("rc1_fromId", "foo0");
		tmpHash.put("rc2_fromId", "foo1");
		tmpHash.put("rc3_fromId", "foo2");

		tmpHash.put("rc1_toId", "bar");
		tmpHash.put("rc2_toId", "bar");
		tmpHash.put("rc3_toId", "bar0");
		// <-- memorizing
		
		//System.out.println(tmpHash);
		
		handler.addRawConnection(rc1);
		handler.addRawConnection(rc2);
		handler.addRawConnection(rc3);

		assertEquals(3, handler.getHashSize());
		
		assertTrue(handler.store("test_connectionhandler_state.xml"));
	}
	
	public void testRetrieve() {
		QConnectionHandler handler = new QConnectionHandler(null);
	
		assertTrue(handler.retrieve("test_connectionhandler_state.xml"));
		
		// See testStore() to understand why this should return 3.
		assertEquals(3, handler.getHashSize());

		RawConnection[] conns = handler.getRawConnections();
		assertEquals(conns.length, handler.getHashSize());
		int index = 1;
		for (RawConnection rc : conns) {
			// rawId
			assertEquals(tmpHash.get(new String("rawId")), rc.getRawId());
			
			// datestamp
			assertEquals(tmpHash.get(new String("datestamp")), 
						 QHeader.DATEFORMAT.format(rc.getAt()));

			// toId
			assertEquals(tmpHash.get(new String("rc" + index + "_toId")), 
						 rc.getTo());
			
			// fromId
			assertEquals(tmpHash.get(new String("rc" + index + "_fromId")), 
						 rc.getFrom());
			
			// connection type
			assertEquals(tmpHash.get(new String("rc" + index + "_type")), 
						 rc.getType());
			index++;
		}
        
        assertFalse(handler.retrieve("nonexistent.file"));
	}
    
    public void testGetRawConnections() {
        QConnectionHandler handler = new QConnectionHandler(null);
        assertEquals(0, handler.getRawConnections().length);
    }

}
