package org.qriterium.unit_tests.util;

import junit.framework.TestCase;

import org.qriterium.statement.QContent;
import org.qriterium.statement.QStatement;
import org.qriterium.util.QStatementIndex;

public class QStatementIndexTest extends TestCase {

    /**
      */
    public void testQStatementIndex() {
        QStatementIndex gi = new QStatementIndex();
        assertTrue(gi.get("foo") == null);
    }


    public void testPutRaw()
    {
        QStatementIndex gi = new QStatementIndex();
        gi.putRaw("four", new Long(4));
        gi.putRaw("three", new Long(3));
        gi.putRaw("three", new Long(2));
        assertTrue(gi.get("four") == 4);
        assertTrue(gi.get("three") == 2);
    }

    public void testPut()
    {
        QStatementIndex gi = new QStatementIndex();
        QContent qs = new QContent("foo", "hello");
        gi.put(qs);
        assertTrue(gi.get("hello") == qs.getId());
    }


    public void testStatementPutGet()
    {
        QStatementIndex gi = new QStatementIndex();
		QStatement st = new QContent("hash1", "rawId");
		QStatement st2 = new QContent("hash1", "rawId2");
		gi.put(st);
		gi.put(st2);
		assertTrue(gi.get("rawId") == st.getId());
		assertTrue(gi.get("rawId2") == st2.getId());
    }
    
    public void testGet()
    {
        QStatementIndex gi = new QStatementIndex();
        gi.putRaw("four", new Long(4));
        gi.putRaw("three", new Long(3));
        gi.putRaw("three", new Long(2));
        assertTrue(gi.get("four") == 4 );
        assertTrue(gi.get("three") == 2 );
        assertNull(gi.get("two"));
    }


    public void testStore()
    {
        QStatementIndex gi = new QStatementIndex();
        gi.putRaw("four", new Long(4));
        gi.putRaw("three", new Long(3));
        gi.putRaw("three", new Long(2));
        gi.store("test.cache");
        assertTrue(gi.get("four") == 4);
        assertTrue(gi.get("three") == 2);
    }


    public void testRetrieve()
    {
        QStatementIndex gi = new QStatementIndex();
        gi.putRaw("four", new Long(4));
        gi.putRaw("three", new Long(3));
        gi.store("test.cache");
        gi.putRaw("three", new Long(2));
        assertTrue(gi.get("four") == 4);
        assertTrue(gi.get("three") == 2);
        assertTrue(gi.retrieve("test.cache"));
        assertTrue(gi.get("four") == 4);
        assertTrue(gi.get("three") == 3);
    }


    public void testBrokenRetrieve()
    {
        QStatementIndex gi = new QStatementIndex();
        gi.putRaw("four", new Long(4));
        gi.putRaw("three", new Long(3));
        gi.putRaw("three", new Long(2));
        assertTrue(gi.get("four") == 4);
        assertTrue(gi.get("three") == 2);
        assertFalse(gi.retrieve("__does__not__Exist__.Cache"));
    }

    public void testBrokenStore()
    {
        QStatementIndex gi = new QStatementIndex();
        gi.putRaw("four", new Long(4));
        gi.putRaw("three", new Long(3));
        gi.putRaw("three", new Long(2));
        assertTrue(gi.get("four") == 4);
        assertTrue(gi.get("three") == 2);
        assertFalse(gi.store("/$#%/\\\\?!?filenames_are@!hard~to`break,no?"));
    }
}
