package org.qriterium.util;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.UUID;
import java.util.logging.Logger;

/**
 * IdFactory is used to return unique id numbers for QStatement.
 * @author ekharkon
 */

public final class IdFactory {	
	private static long nextID;
	private static String serialID;

	private static Logger logger = Logger.getLogger("org.qriterium.util.IdFactory");
	
	static {
		nextID = 1;
		serialID = UUID.randomUUID().toString();
	}

	public static String getSerialID() {
		return serialID;
	}
	
	/**
	 * Returns new id that is guaranteed to be unique.
	 * @return 	new unique id
	 */
	public static synchronized long getUniqueId() {
		long id;
		
		id = nextID;
		nextID++;
		
		return id;
	}

	/**
	 * Returns next unique id that will be returned with getUniqueId
	 * @return 	next unique id
	 */
	public static synchronized long getState() {
		return nextID;
	}
	
	public static boolean store(String stateFile) {
		FileOutputStream out = null;
		try {
			out = new FileOutputStream(stateFile);
			ObjectOutputStream objectStream = new ObjectOutputStream(out);
			objectStream.writeObject(serialID);
			objectStream.writeLong(nextID);
			objectStream.close();
			out.close();
		} catch (IOException e) {
			logger.severe("Cannot save Id state to file : " + stateFile);
			return false;
		}
		return true;
	}

	public static boolean retrieve(String stateFile) {
		try {
			FileInputStream in = new FileInputStream(stateFile);
			ObjectInputStream objectStream = new ObjectInputStream(in);
			serialID = (String) objectStream.readObject();
			nextID = objectStream.readLong();
			objectStream.close();
			in.close();
		} catch (FileNotFoundException e) {
			logger.warning("No previous Id state found.");
			logger.warning("Id numbers will now start from 1.");
		} catch (Exception e) {
			logger.severe("Cannot read Id state from file : " + stateFile);
			return false;
		}
		return true;
	}
}
