package org.qriterium.util;

import java.text.ParseException;
import java.util.TreeMap;

import org.qriterium.statement.QHeader;
import org.qriterium.statement.RawConnection;
import org.xml.sax.Attributes;
import org.xml.sax.helpers.DefaultHandler;

public class QConnectionHandlerCacheHandler extends DefaultHandler {

	enum Phase {NONE, CONNECTION, RAWID, CREATED_AT, FROMRAWID, TORAWID, CONNECTIONTYPE, HASH};
	Phase phase = Phase.CONNECTION;
	Phase expected = Phase.CONNECTION;
	
	TreeMap<String,RawConnection> rawConnections;
	QConnectionHandler connectionHandler;
	private RawConnection rawConnection; 
	private String rawId;
	private String createdAt;
	private String fromRawId;
	private String toRawId;
	private String connectionType;
	private String hash;
	
	public QConnectionHandlerCacheHandler(QConnectionHandler connectionHandler, TreeMap<String,RawConnection> rawConnections) {
		super();
		this.connectionHandler = connectionHandler;
		this.rawConnections = rawConnections;
	}

	public void startElement(String uri, String localName, String qName, Attributes atts) {
		if (qName.equals(QConnectionHandler.XMLELEMENT_CONNECTION)) {
			this.phase = Phase.CONNECTION;
			this.rawConnection = null;
			this.rawId = null;
			this.createdAt = null;
			this.fromRawId = null;
			this.toRawId = null;
			this.connectionType = null;
			this.hash = null;
		}
		
		if (qName.equals(QConnectionHandler.XMLELEMENT_RAWID)) {
			this.phase = Phase.RAWID;
		}
		if (qName.equals(QConnectionHandler.XMLELEMENT_CREATEDAT)) {
			this.phase = Phase.CREATED_AT;
		}
		if (qName.equals(QConnectionHandler.XMLELEMENT_FROMRAWID)) {
			this.phase = Phase.FROMRAWID;
		}
		if (qName.equals(QConnectionHandler.XMLELEMENT_TORAWID)) {
			this.phase = Phase.TORAWID;
		}
		if (qName.equals(QConnectionHandler.XMLELEMENT_CONNECTIONTYPE)) {
				this.phase = Phase.CONNECTIONTYPE;
		}
		if (qName.equals(QConnectionHandler.XMLELEMENT_HASH)) {
			this.phase = Phase.HASH;
		}
	}

	public void endElement(String uri, String localName, String qName) {
		if (qName.equals(QConnectionHandler.XMLELEMENT_CONNECTION)) {
			try {
				this.rawConnection = new RawConnection(this.fromRawId, 
													this.toRawId, 
													this.connectionType, 
													this.hash, 
													this.rawId,
													QHeader.DATEFORMAT.parse(this.createdAt));
			} catch (ParseException e) {
				this.rawConnection = new RawConnection(this.fromRawId, 
						this.toRawId, 
						this.connectionType, 
						this.hash, 
						this.rawId);
			}
			this.rawConnections.put(this.connectionHandler.nextUniqueKey(this.toRawId), this.rawConnection);
			//System.out.println("added rawconnection: " + this.rawConnection);
		}
		
		/* SAX thinks you want the whitespace after end tag too, but that's 
		 * not the case obviously */
		this.phase = Phase.NONE;
	}

	public void characters(char[] ch, int start, int end) {
		switch (this.phase) {
			case RAWID:
				this.rawId = new String(ch, start, end);
				break;
			case CREATED_AT:
				this.createdAt = new String(ch, start, end);
				break;
			case FROMRAWID:
				this.fromRawId = new String(ch, start, end);
				break;
			case TORAWID:
				this.toRawId = new String(ch, start, end);
				break;
			case CONNECTIONTYPE:
				this.connectionType = new String(ch, start, end);
				break;
			case HASH:
				this.hash = new String(ch, start, end);
				break;
		}
	}
}
